@@ -149,6 +149,35 @@ class ATMOSPHERE_1976(object):
        http://www.dtic.mil/cgi-bin/GetTRDoc?AD=ADA588839
     '''
     R = 8314.32
+
+    def __init__(self, Z, dT=0.0):
+        self.Z = Z
+        self.dT = dT
+        self.H = r0*Z/(r0+Z)
+
+        i = self._get_ind_from_H(self.H)
+        self.T_layer = T_std[i]
+        self.T_increase = T_grad[i]
+        self.P_layer = P_std[i]
+        self.H_layer = H_std[i]
+
+        self.H_above_layer = self.H - self.H_layer
+        self.T = self.T_layer + self.T_increase*self.H_above_layer
+
+        if self.T_increase == 0.0:
+            self.P = self.P_layer*exp(-g0*M0*(self.H_above_layer)/(self.R*self.T_layer))
+        else:
+            self.P = self.P_layer*(self.T_layer/self.T)**(g0*M0/(self.R*self.T_increase))
+
+        # Affects only the following properties
+        self.T += dT
+            
+            
+        self.rho = self.density(self.T, self.P)
+        self.v_sonic = self.sonic_velocity(self.T)
+        self.mu = self.viscosity(self.T)
+        self.k = self.thermal_conductivity(self.T)
+        self.g = self.gravity(self.Z)
     
     @staticmethod
     def _get_ind_from_H(H):
@@ -156,11 +185,11 @@ class ATMOSPHERE_1976(object):
         the index of the layer a specified elevation is above. Levels are 
         0, 11E3, 20E3, 32E3, 47E3, 51E3, 71E3, 84852 meters respectively.
         '''
-        if H <= 0:
+        if H <= 0.0:
             return 0
         for ind, Hi in enumerate(H_std):
             if Hi >= H :
-                return ind-1
+                return ind - 1
         return 7 # case for > 84852 m.
     
     @staticmethod
@@ -267,7 +296,8 @@ class ATMOSPHERE_1976(object):
         -------
         g : float
             Acceleration due to gravity, [m/s^2]
-        '''        
+        '''
+        
         return g0*(r0/(r0+Z))**2
 
     @staticmethod
@@ -310,34 +340,6 @@ class ATMOSPHERE_1976(object):
         from scipy.integrate import quad
         return float(quad(to_int, H_ref, H_ref+dH)[0])
 
-    def __init__(self, Z, dT=0):
-        self.Z = Z
-        self.dT = dT
-        self.H = r0*self.Z/(r0+self.Z)
-
-        i = self._get_ind_from_H(self.H)
-        self.T_layer = T_std[i]
-        self.T_increase = T_grad[i]
-        self.P_layer = P_std[i]
-        self.H_layer = H_std[i]
-
-        self.H_above_layer = self.H - self.H_layer
-        self.T = self.T_layer + self.T_increase*self.H_above_layer
-
-        if self.T_increase == 0:
-            self.P = self.P_layer*exp(-g0*M0*(self.H_above_layer)/self.R/self.T_layer)
-        else:
-            self.P = self.P_layer*(self.T_layer/self.T)**(g0*M0/self.R/self.T_increase)
-
-        if dT: # Affects only the following properties
-            self.T += dT
-            
-            
-        self.rho = self.density(self.T, self.P)
-        self.v_sonic = self.sonic_velocity(self.T)
-        self.mu = self.viscosity(self.T)
-        self.k = self.thermal_conductivity(self.T)
-        self.g = self.gravity(self.Z)
     
 
 class ATMOSPHERE_NRLMSISE00(object):
@@ -678,10 +680,13 @@ def hwm14(Z, latitude=0, longitude=0, day=0, seconds=0,
     # Needed by hwm14
     os.environ["HWMPATH"] = os.path.join(os.path.dirname(__file__), 'optional')
     try:
-        import optional.hwm14
+        try:
+            from .optional import hwm14
+        except:
+            import optional.hwm14
     except: # pragma: no cover
         raise ImportError(no_gfortran_error)
-    ans = optional.hwm14.hwm14(day, seconds, Z/1000., latitude, longitude, 0, 0, 
+    ans = hwm14.hwm14(day, seconds, Z/1000., latitude, longitude, 0, 0, 
                0, np.array([np.nan, geomagnetic_disturbance_index]))
     return tuple(ans.tolist())
 
@@ -736,18 +741,25 @@ def airmass(func, angle, H_max=86400.0, R_planet=6.371229E6, RI=1.000276):
        1989): 4735-38. https://doi.org/10.1364/AO.28.004735.
     '''
     delta0 = RI - 1.0
-    rho0 = func(0.0)
+    rho0_inv = 1.0/func(0.0)
     angle_term = cos(radians(angle)) 
+    R_planet_inv = 1.0/R_planet
+    
+    c0 = delta0 + delta0
+    c1 = c0*rho0_inv
+    c2 = 1.0 + c0
     
     def to_int(Z):
+        Z = float(Z)
         rho = func(Z)
-        t1 = (1.0 + 2.0*delta0*(1.0 - rho/rho0))
-        t2 = (angle_term/(1.0 + Z/R_planet))**2
+        t1 = c2 - rho*c1
+        x0 = angle_term/(1.0 + Z*R_planet_inv)
+        t2 = x0*x0
         t3 = (1.0 - t1*t2)**-0.5
         return rho*t3
 
     from scipy.integrate import quad
-    return float(quad(to_int, 0, 86400.0)[0])
+    return float(quad(to_int, 0.0, 86400.0)[0])
 
 
 
