@@ -22,7 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
 from __future__ import division
-from scipy.constants import g
+from fluids.constants import g
 from math import log, pi
 
 __all__ = ['agitator_time_homogeneous',
