@@ -36,14 +36,42 @@ from scipy import linalg
 
 from scipy.interpolate import BarycentricInterpolator as Bary
 import numpy.polynomial as poly
+from numpy.polynomial.chebyshev import cheb2poly, Chebyshev
+from numpy.polynomial.polynomial import Polynomial
+
 import scipy.fftpack as fftpack
 
 import sys
 emach = sys.float_info.epsilon # machine epsilon
 
 
+def build_pychebfun(f, domain, N=15):
+    fvec = lambda xs: [f(xi) for xi in xs]
+    return chebfun(f=fvec, domain=domain, N=N)
+
+
+def build_solve_pychebfun(f, goal, domain, N=15, N_max=100, find_roots=2):
+    cache = {}
+    def cached_fun(x):
+        # Almost half the points are cached!
+        if x in cache:
+            return cache[x]
+        val = f(x)
+        cache[x] = val
+        return val
+    
+    fun = build_pychebfun(cached_fun, domain, N=N)
+    roots = (fun - goal).roots()
+    
+    while (len(roots) < find_roots and len(fun._values) < N_max):
+        N *= 2
+        fun = build_pychebfun(cached_fun, domain, N=N)
+        roots = (fun - goal).roots()
+        roots = [i for i in roots if domain[0] < i < domain[1]]
+        
+    return roots, fun
+
 def chebfun_to_poly(fun, text=False):
-    from numpy.polynomial.chebyshev import cheb2poly
     low, high = fun._domain
     # Reverse the coefficients, and use cheb2poly to make it in the polynomial domain
     poly_coeffs = cheb2poly(fun.coefficients())[::-1].tolist()
@@ -57,6 +85,24 @@ def chebfun_to_poly(fun, text=False):
     # return the string
     return s
 
+def cheb_to_poly(coeffs_or_fun, domain=None):
+    '''Just call horner on the outputs!
+    '''
+    from fluids.numerics import horner as horner_poly
+    
+    if isinstance(coeffs_or_fun, Chebfun):
+        coeffs = coeffs_or_fun.coefficients()
+        domain = coeffs_or_fun._domain
+    else:
+        coeffs = coeffs_or_fun
+
+    low, high = domain
+    coeffs = cheb2poly(coeffs)[::-1].tolist() # Convert to polynomial basis
+    # Mix in limits to make it a normal polynomial
+    my_poly = Polynomial([-0.5*(high + low)*2.0/(high - low), 2.0/(high - low)])
+    poly_coeffs = horner_poly(coeffs, my_poly).coef[::-1].tolist()
+    return poly_coeffs
+
 
 def cheb_range_simplifier(low, high, text=False):
     '''
@@ -514,12 +560,18 @@ class Chebfun(Polyfun):
             scaled_roots = self._ui_to_ab(np.array(roots))
             return scaled_roots
         else:
-            # divide at a close-to-zero split-point
-            split_point = self._ui_to_ab(0.0123456789)
-            return np.concatenate(
-                (self.restrict([self._domain[0],split_point]).roots(),
-                 self.restrict([split_point,self._domain[1]]).roots())
-            )
+            try:
+                # divide at a close-to-zero split-point
+                split_point = self._ui_to_ab(0.0123456789)
+                return np.concatenate(
+                    (self.restrict([self._domain[0],split_point]).roots(),
+                     self.restrict([split_point,self._domain[1]]).roots()))
+            except:
+                # Seems to have many fake roots for high degree fits
+                coeffs = self.coefficients()
+                domain = self._domain
+                possibilities =  Chebyshev(coeffs, domain).roots()
+                return np.array([float(i.real) for i in possibilities if i.imag == 0.0])
 
     # ----------------------------------------------------------------
     # Interpolation and evaluation (go from values to coefficients)
@@ -698,6 +750,8 @@ for func in [np.arccos, np.arccosh, np.arcsin, np.arcsinh, np.arctan, np.arctanh
 # Constructor inspired by the Matlab version
 # ----------------------------------------------------------------
 
+
+
 def chebfun(f=None, domain=[-1,1], N=None, chebcoeff=None,):
     """
     Create a Chebyshev polynomial approximation of the function $f$ on the interval :math:`[-1, 1]`.
