@@ -22,7 +22,7 @@ SOFTWARE.'''
 
 from __future__ import division
 from math import pi
-from scipy.constants import inch
+from fluids.constants import inch
 
 __all__ = ['nearest_pipe', 'gauge_from_t', 't_from_gauge', 'wire_schedules']
 
