@@ -22,9 +22,8 @@ SOFTWARE.'''
 
 from __future__ import division
 from math import log, exp, pi
-from scipy.constants import g
-from scipy.interpolate import UnivariateSpline
-from scipy.constants import foot, psi
+from fluids.constants import g, foot, psi
+from fluids.numerics import splev, implementation_optimize_tck
 
 __all__ = ['v_Sounders_Brown', 'K_separator_Watkins',
            'K_separator_demister_York', 'K_Sounders_Brown_theoretical']
@@ -35,38 +34,18 @@ __all__ = ['v_Sounders_Brown', 'K_separator_Watkins',
 # it produced was selected plus the last point. The initial value is adjusted 
 # to be the lower limit of the graph.
 
-v_factors_Watkins = [0.006, 0.00649546, 0.00700535, 0.00755527, 0.00817788,
-    0.00881991, 0.00954676, 0.0103522, 0.0112256, 0.0121947, 0.0132476,
-    0.0143655, 0.0156059, 0.0169841, 0.018484, 0.0201165, 0.0219329,
-    0.0239133, 0.0260727, 0.0284272, 0.0309944, 0.0339158, 0.037046,
-    0.0403924, 0.0441998, 0.0483665, 0.0529259, 0.0579153, 0.0632613,
-    0.0692251, 0.0756157, 0.0825962, 0.0902214, 0.0983732, 0.107262,
-    0.116954, 0.127753, 0.139047, 0.151614, 0.165317, 0.179934, 0.195845,
-    0.21278, 0.231181, 0.251627, 0.272897, 0.295966, 0.32041, 0.347497,
-    0.3762, 0.407274, 0.440914, 0.476478, 0.513983, 0.554442, 0.59701,
-    0.642851, 0.690966, 0.744018, 0.798268, 0.856477, 0.920588, 0.987716,
-    1.05784, 1.13294, 1.21337, 1.29718, 1.38678, 1.4799, 1.58212, 1.68837,
-    1.79851, 1.91583, 2.04083, 2.16616, 2.29918, 2.44037, 2.59025, 2.73944,
-    2.89725, 3.06414, 3.24064, 3.42731, 3.61822, 3.81976, 4.02527, 4.24949,
-    4.47008, 4.71907, 4.96404, 5.22172, 5.43354]
-
-Kv_Watkins = [0.23722, 0.248265, 0.260298, 0.272915, 0.284578, 0.297283,
-    0.309422, 0.322054, 0.33398, 0.345714, 0.355905, 0.366397, 0.377197,
-    0.386898, 0.396125, 0.404831, 0.411466, 0.41821, 0.424289, 0.428886,
-    0.433533, 0.435832, 0.436547, 0.436468, 0.437982, 0.437898, 0.437815,
-    0.436932, 0.435258, 0.434381, 0.431138, 0.427919, 0.42395, 0.420018,
-    0.415364, 0.410012, 0.403988, 0.39733, 0.390067, 0.38154, 0.373883,
-    0.364378, 0.354467, 0.344197, 0.333613, 0.322767, 0.311704, 0.299923,
-    0.289114, 0.277173, 0.265725, 0.254749, 0.243338, 0.232438, 0.221621,
-    0.211309, 0.200742, 0.190704, 0.181498, 0.172108, 0.162906, 0.154196,
-    0.145952, 0.137897, 0.130049, 0.122647, 0.115667, 0.108885, 0.102502,
-    0.0963159, 0.0903385, 0.0847323, 0.0796194, 0.0744062, 0.0695348,
-    0.0651011, 0.060839, 0.0567521, 0.0529401, 0.0492041, 0.0458154,
-    0.0426601, 0.039722, 0.036919, 0.0343137, 0.0318924, 0.0296419,
-    0.0275001, 0.0255595, 0.0237127, 0.0219993, 0.0207107]
-Watkins_interp = UnivariateSpline(v_factors_Watkins, Kv_Watkins, s=.00001)
-
 
+tck_Watkins = implementation_optimize_tck([[-5.115995809754082, -5.115995809754082, -5.115995809754082,
+                                            -5.115995809754082, -4.160106231099973, -3.209113630523477,
+                                            -1.2175106961204154, 0.4587657198189318, 1.1197669427405068,
+                                            1.6925908552310418, 1.6925908552310418, 1.6925908552310418,
+                                            1.6925908552310418],
+                                        [-1.4404286048266364, -1.2375168139385286, -0.9072614905522024,
+                                         -0.7662335745829165, -0.944537665617708, -1.957339717378027,
+                                         -3.002614318094637, -3.5936804378352956, -3.8779153181940553,
+                                         0.0, 0.0, 0.0, 0.0],
+                                         3])
+                            
 def K_separator_Watkins(x, rhol, rhog, horizontal=False, method='spline'):
     r'''Calculates the Sounders-Brown `K` factor as used in determining maximum 
     allowable gas velocity in a two-phase separator in either a horizontal or
@@ -133,7 +112,7 @@ def K_separator_Watkins(x, rhol, rhog, horizontal=False, method='spline'):
     Examples
     --------
     >>> K_separator_Watkins(0.88, 985.4, 1.3, horizontal=True)
-    0.07944704064029771
+    0.07951613600476297
 
     References
     ----------
@@ -146,7 +125,7 @@ def K_separator_Watkins(x, rhol, rhog, horizontal=False, method='spline'):
     '''
     factor = (1. - x)/x*(rhog/rhol)**0.5
     if method == 'spline':
-        K = float(Watkins_interp(factor))
+        K = exp(float(splev(log(factor), tck_Watkins)))
     elif method == 'blackwell':
         X = log(factor)    
         A = -1.877478097
