@@ -53,9 +53,9 @@ def func_args(func):
     method.
     '''
     try:
-        return tuple(inspect.signature(func).parameters)
-    except:
         return tuple(inspect.getargspec(func).args)
+    except:
+        return tuple(inspect.getfullargspec(func).args)
 
 u.autoconvert_offset_to_baseunit = True
 
@@ -65,7 +65,7 @@ expr2 = re.compile('Returns *\n *-+\n +')
 match_sections = re.compile('\n *[A-Za-z ]+ *\n +-+')
 match_section_names = re.compile('\n *[A-Za-z]+ *\n +-+')
 variable = re.compile('[a-zA-Z_0-9]* : ')
-match_units = re.compile('\[[a-zA-Z0-9()./*^\- ]*\]')
+match_units = re.compile(r'\[[a-zA-Z0-9().\/*^\- ]*\]')
 
 
 def parse_numpydoc_variables_units(func):
@@ -118,9 +118,15 @@ def check_args_order(func):
     Other Parameters with the input arguments of the actual function signature.
     Raises an exception if not correctly defined.
     
+    getargspec is used for Python 2.7 compatibility and is deprecated in Python
+    3.
+    
     >>> check_args_order(fluids.core.Reynolds)
     '''
-    argspec = inspect.getargspec(func)
+    try:
+        argspec = inspect.getfullargspec(func)
+    except:
+        argspec = inspect.getargspec(func)
     parsed_data = parse_numpydoc_variables_units(func)
     # compare the parsed arguments with those actually defined
     parsed_units = parsed_data['Parameters']['units']
@@ -135,7 +141,10 @@ def check_args_order(func):
     
     
 def match_parse_units(doc, i=-1):
-    matches = match_units.findall(doc)
+    if doc is None:
+        matches = ['[]']
+    else:
+        matches = match_units.findall(doc)
     if len(matches) == 0:
         # If there is no unit listed, assume it's dimensionless (probably a string)
         matches = ['[]']
@@ -361,12 +370,12 @@ def wrap_numpydoc_obj(obj_to_wrap):
     for i in dir(obj_to_wrap):
         attr = getattr(obj_to_wrap, i)
         if isinstance(attr, types.FunctionType) or isinstance(attr, types.MethodType) or type(attr) == property:
-            if type(attr) == property:
+            if type(attr) is property:
                 name = attr.fget.__name__
             else:
                 name = attr.__name__
             if hasattr(attr, '__doc__'):
-                if type(attr) == property:
+                if type(attr) is property:
                     property_unit_map[name] = u(match_parse_units(attr.fget.__doc__, i=0))
                 else:
                     parsed = parse_numpydoc_variables_units(attr)
@@ -565,4 +574,3 @@ def differential_pressure_meter_solver(D, rho, mu, k, D2=None, P1=None, P2=None,
     elif P1 is None and (None not in [D, D2, m, P2]):
         return ans*u.Pa
 
-### TODO list
