@@ -41,7 +41,9 @@ def test_cooling_degree_days():
     assert_allclose(cooling_degree_days(300, truncate=False), -16.85)
     assert_allclose(cooling_degree_days(250, T_base=300), 50)
 
+
 @pytest.mark.slow
+@pytest.mark.online
 def test_month_average_temperature():
     station = get_closest_station(38.8572, -77.0369)
     station_data = StationDataGSOD(station)
@@ -456,3 +458,9 @@ def test_get_station_year_text():
     with pytest.raises(Exception):
         get_station_year_text(712650, 99999, 19999999999)
 
+
+@pytest.mark.slow
+@pytest.mark.online
+def test_geocode():
+    latlon = geocode('Fredericton, NB')
+    assert_allclose(latlon, (45.966425, -66.645813), rtol=1e-4)
\ No newline at end of file
