@@ -134,6 +134,9 @@ def test_entrance_distance():
     K = entrance_distance(Di=0.1, t=0.0005, method='Harris')
     assert_allclose(K, 0.8705806231290558, 3e-3)
     
+    K = entrance_distance(Di=0.1, method='Crane')
+    assert_allclose(K, 0.78)
+    
     with pytest.raises(Exception):
         entrance_distance(Di=0.1, t=0.01, method='BADMETHOD')
 
@@ -155,9 +158,17 @@ def test_entrance_rounded():
     K = entrance_rounded(Di=0.1, rc=0.01, method='Harris')
     assert_allclose(K, 0.04864878230217168)
     
+    # Limiting condition
+    K = entrance_rounded(Di=0.1, rc=0.0235, method='Harris')
+    assert_allclose(K, 0.0)
+    
     K = entrance_rounded(Di=0.1, rc=0.01, method='Idelchik')
     assert_allclose(K, 0.11328005177738182)
     
+    # Limiting condition
+    K = entrance_rounded(Di=0.1, rc=0.0235, method='Idelchik')
+    assert_allclose(K, 0.03)
+    
     with pytest.raises(Exception):
         entrance_rounded(Di=0.1, rc=0.01, method='BADMETHOD')
 
@@ -337,6 +348,13 @@ def test_diffuser_conical():
     K2 = diffuser_conical(Di1=1., Di2=10.,l=9, fd=0.01)
     Ks = [1.7681854713484308, 0.973137914861591]
     assert_allclose([K1, K2], Ks)
+    
+    # Idelchilk
+    Ks_Idelchik = [diffuser_conical(Di1=.1**0.5, Di2=1, l=l,  method='Idelchik') for l in [.1, .5, 1, 2, 3, 4, 5, 20]]
+    Ks_Idelchik_expect = [0.8617385829640242, 0.9283647028367953, 0.7082429168951839, 0.291016580744589, 0.18504484868875992, 0.147705693811332, 0.12911637682462676, 0.17]
+    assert_allclose(Ks_Idelchik, Ks_Idelchik_expect, rtol=1e-2)
+
+
 
 
 ### Contractions
